# Print an optspec for argparse to handle cmd's options that are independent of any subcommand.
function __fish_maturin_global_optspecs
	string join \n v/verbose h/help V/version
end

function __fish_maturin_needs_command
	# Figure out if the current invocation already has a command.
	set -l cmd (commandline -opc)
	set -e cmd[1]
	argparse -s (__fish_maturin_global_optspecs) -- $cmd 2>/dev/null
	or return
	if set -q argv[1]
		# Also print the command, so this can be used to figure out what it is.
		echo $argv[1]
		return 1
	end
	return 0
end

function __fish_maturin_using_subcommand
	set -l cmd (__fish_maturin_needs_command)
	test -z "$cmd"
	and return 1
	contains -- $cmd[1] $argv
end

complete -c maturin -n "__fish_maturin_needs_command" -s v -l verbose -d 'Use verbose output'
complete -c maturin -n "__fish_maturin_needs_command" -s h -l help -d 'Print help (see more with \'--help\')'
complete -c maturin -n "__fish_maturin_needs_command" -s V -l version -d 'Print version'
complete -c maturin -n "__fish_maturin_needs_command" -f -a "build" -d 'Build the crate into python packages'
complete -c maturin -n "__fish_maturin_needs_command" -f -a "list-python" -d 'Search and list the available python installations'
complete -c maturin -n "__fish_maturin_needs_command" -f -a "develop" -d 'Install the crate as module in the current virtualenv'
complete -c maturin -n "__fish_maturin_needs_command" -f -a "sdist" -d 'Build only a source distribution (sdist) without compiling'
complete -c maturin -n "__fish_maturin_needs_command" -f -a "init" -d 'Create a new cargo project in an existing directory'
complete -c maturin -n "__fish_maturin_needs_command" -f -a "new" -d 'Create a new cargo project'
complete -c maturin -n "__fish_maturin_needs_command" -f -a "generate-ci" -d 'Generate CI configuration'
complete -c maturin -n "__fish_maturin_needs_command" -f -a "pep517" -d 'Backend for the PEP 517 integration. Not for human consumption'
complete -c maturin -n "__fish_maturin_needs_command" -f -a "completions" -d 'Generate shell completions'
complete -c maturin -n "__fish_maturin_needs_command" -f -a "help" -d 'Print this message or the help of the given subcommand(s)'
complete -c maturin -n "__fish_maturin_using_subcommand build" -l compatibility -d 'Control the platform tag on linux' -r
complete -c maturin -n "__fish_maturin_using_subcommand build" -s i -l interpreter -d 'The python versions to build wheels for, given as the executables of interpreters such as `python3.9` or `/usr/bin/python3.8`' -r -F
complete -c maturin -n "__fish_maturin_using_subcommand build" -s b -l bindings -d 'Which kind of bindings to use' -r -f -a "{pyo3\t'',pyo3-ffi\t'',cffi\t'',uniffi\t'',bin\t''}"
complete -c maturin -n "__fish_maturin_using_subcommand build" -s o -l out -d 'The directory to store the built wheels in. Defaults to a new "wheels" directory in the project\'s target directory' -r -F
complete -c maturin -n "__fish_maturin_using_subcommand build" -l auditwheel -d 'Audit wheel for manylinux compliance' -r -f -a "{repair\t'Audit and repair wheel for manylinux compliance',check\t'Check wheel for manylinux compliance, but do not repair',skip\t'Don\'t check for manylinux compliance'}"
complete -c maturin -n "__fish_maturin_using_subcommand build" -s j -l jobs -d 'Number of parallel jobs, defaults to # of CPUs' -r
complete -c maturin -n "__fish_maturin_using_subcommand build" -l profile -d 'Build artifacts with the specified Cargo profile' -r
complete -c maturin -n "__fish_maturin_using_subcommand build" -s F -l features -d 'Space or comma separated list of features to activate' -r
complete -c maturin -n "__fish_maturin_using_subcommand build" -l target -d 'Build for the target triple' -r
complete -c maturin -n "__fish_maturin_using_subcommand build" -l target-dir -d 'Directory for all generated artifacts' -r -F
complete -c maturin -n "__fish_maturin_using_subcommand build" -s m -l manifest-path -d 'Path to Cargo.toml' -r -F
complete -c maturin -n "__fish_maturin_using_subcommand build" -l color -d 'Coloring: auto, always, never' -r
complete -c maturin -n "__fish_maturin_using_subcommand build" -l config -d 'Override a configuration value (unstable)' -r
complete -c maturin -n "__fish_maturin_using_subcommand build" -s Z -d 'Unstable (nightly-only) flags to Cargo, see \'cargo -Z help\' for details' -r
complete -c maturin -n "__fish_maturin_using_subcommand build" -l timings -d 'Timing output formats (unstable) (comma separated): html, json' -r
complete -c maturin -n "__fish_maturin_using_subcommand build" -s r -l release -d 'Build artifacts in release mode, with optimizations'
complete -c maturin -n "__fish_maturin_using_subcommand build" -l strip -d 'Strip the library for minimum file size'
complete -c maturin -n "__fish_maturin_using_subcommand build" -l sdist -d 'Build a source distribution'
complete -c maturin -n "__fish_maturin_using_subcommand build" -s f -l find-interpreter -d 'Find interpreters from the host machine'
complete -c maturin -n "__fish_maturin_using_subcommand build" -l skip-auditwheel -d 'Don\'t check for manylinux compliance'
complete -c maturin -n "__fish_maturin_using_subcommand build" -s q -l quiet -d 'Do not print cargo log messages'
complete -c maturin -n "__fish_maturin_using_subcommand build" -l all-features -d 'Activate all available features'
complete -c maturin -n "__fish_maturin_using_subcommand build" -l no-default-features -d 'Do not activate the `default` feature'
complete -c maturin -n "__fish_maturin_using_subcommand build" -l ignore-rust-version -d 'Ignore `rust-version` specification in packages'
complete -c maturin -n "__fish_maturin_using_subcommand build" -s v -l verbose -d 'Use verbose output (-vv very verbose/build.rs output)'
complete -c maturin -n "__fish_maturin_using_subcommand build" -l frozen -d 'Require Cargo.lock and cache are up to date'
complete -c maturin -n "__fish_maturin_using_subcommand build" -l locked -d 'Require Cargo.lock is up to date'
complete -c maturin -n "__fish_maturin_using_subcommand build" -l offline -d 'Run without accessing the network'
complete -c maturin -n "__fish_maturin_using_subcommand build" -l future-incompat-report -d 'Outputs a future incompatibility report at the end of the build (unstable)'
complete -c maturin -n "__fish_maturin_using_subcommand build" -s h -l help -d 'Print help (see more with \'--help\')'
complete -c maturin -n "__fish_maturin_using_subcommand list-python" -l target -r
complete -c maturin -n "__fish_maturin_using_subcommand list-python" -s v -l verbose -d 'Use verbose output'
complete -c maturin -n "__fish_maturin_using_subcommand list-python" -s h -l help -d 'Print help (see more with \'--help\')'
complete -c maturin -n "__fish_maturin_using_subcommand develop" -s b -l bindings -d 'Which kind of bindings to use' -r -f -a "{pyo3\t'',pyo3-ffi\t'',cffi\t'',uniffi\t'',bin\t''}"
complete -c maturin -n "__fish_maturin_using_subcommand develop" -s E -l extras -d 'Install extra requires aka. optional dependencies' -r
complete -c maturin -n "__fish_maturin_using_subcommand develop" -l pip-path -d 'Use a specific pip installation instead of the default one' -r -F
complete -c maturin -n "__fish_maturin_using_subcommand develop" -s j -l jobs -d 'Number of parallel jobs, defaults to # of CPUs' -r
complete -c maturin -n "__fish_maturin_using_subcommand develop" -l profile -d 'Build artifacts with the specified Cargo profile' -r
complete -c maturin -n "__fish_maturin_using_subcommand develop" -s F -l features -d 'Space or comma separated list of features to activate' -r
complete -c maturin -n "__fish_maturin_using_subcommand develop" -l target -d 'Build for the target triple' -r
complete -c maturin -n "__fish_maturin_using_subcommand develop" -l target-dir -d 'Directory for all generated artifacts' -r -F
complete -c maturin -n "__fish_maturin_using_subcommand develop" -s m -l manifest-path -d 'Path to Cargo.toml' -r -F
complete -c maturin -n "__fish_maturin_using_subcommand develop" -l color -d 'Coloring: auto, always, never' -r
complete -c maturin -n "__fish_maturin_using_subcommand develop" -l config -d 'Override a configuration value (unstable)' -r
complete -c maturin -n "__fish_maturin_using_subcommand develop" -s Z -d 'Unstable (nightly-only) flags to Cargo, see \'cargo -Z help\' for details' -r
complete -c maturin -n "__fish_maturin_using_subcommand develop" -l timings -d 'Timing output formats (unstable) (comma separated): html, json' -r
complete -c maturin -n "__fish_maturin_using_subcommand develop" -s r -l release -d 'Pass --release to cargo'
complete -c maturin -n "__fish_maturin_using_subcommand develop" -l strip -d 'Strip the library for minimum file size'
complete -c maturin -n "__fish_maturin_using_subcommand develop" -l skip-install -d 'Skip installation, only build the extension module inplace'
complete -c maturin -n "__fish_maturin_using_subcommand develop" -s q -l quiet -d 'Do not print cargo log messages'
complete -c maturin -n "__fish_maturin_using_subcommand develop" -l all-features -d 'Activate all available features'
complete -c maturin -n "__fish_maturin_using_subcommand develop" -l no-default-features -d 'Do not activate the `default` feature'
complete -c maturin -n "__fish_maturin_using_subcommand develop" -l ignore-rust-version -d 'Ignore `rust-version` specification in packages'
complete -c maturin -n "__fish_maturin_using_subcommand develop" -s v -l verbose -d 'Use verbose output (-vv very verbose/build.rs output)'
complete -c maturin -n "__fish_maturin_using_subcommand develop" -l frozen -d 'Require Cargo.lock and cache are up to date'
complete -c maturin -n "__fish_maturin_using_subcommand develop" -l locked -d 'Require Cargo.lock is up to date'
complete -c maturin -n "__fish_maturin_using_subcommand develop" -l offline -d 'Run without accessing the network'
complete -c maturin -n "__fish_maturin_using_subcommand develop" -l future-incompat-report -d 'Outputs a future incompatibility report at the end of the build (unstable)'
complete -c maturin -n "__fish_maturin_using_subcommand develop" -l uv -d 'Use `uv` to install packages instead of `pip`'
complete -c maturin -n "__fish_maturin_using_subcommand develop" -s h -l help -d 'Print help (see more with \'--help\')'
complete -c maturin -n "__fish_maturin_using_subcommand sdist" -s m -l manifest-path -d 'The path to the Cargo.toml' -r -F
complete -c maturin -n "__fish_maturin_using_subcommand sdist" -s o -l out -d 'The directory to store the built wheels in. Defaults to a new "wheels" directory in the project\'s target directory' -r -F
complete -c maturin -n "__fish_maturin_using_subcommand sdist" -s v -l verbose -d 'Use verbose output'
complete -c maturin -n "__fish_maturin_using_subcommand sdist" -s h -l help -d 'Print help (see more with \'--help\')'
complete -c maturin -n "__fish_maturin_using_subcommand init" -l name -d 'Set the resulting package name, defaults to the directory name' -r
complete -c maturin -n "__fish_maturin_using_subcommand init" -s b -l bindings -d 'Which kind of bindings to use' -r -f -a "{pyo3\t'',cffi\t'',uniffi\t'',bin\t''}"
complete -c maturin -n "__fish_maturin_using_subcommand init" -l mixed -d 'Use mixed Rust/Python project layout'
complete -c maturin -n "__fish_maturin_using_subcommand init" -l src -d 'Use Python first src layout for mixed Rust/Python project'
complete -c maturin -n "__fish_maturin_using_subcommand init" -s v -l verbose -d 'Use verbose output'
complete -c maturin -n "__fish_maturin_using_subcommand init" -s h -l help -d 'Print help (see more with \'--help\')'
complete -c maturin -n "__fish_maturin_using_subcommand new" -l name -d 'Set the resulting package name, defaults to the directory name' -r
complete -c maturin -n "__fish_maturin_using_subcommand new" -s b -l bindings -d 'Which kind of bindings to use' -r -f -a "{pyo3\t'',cffi\t'',uniffi\t'',bin\t''}"
complete -c maturin -n "__fish_maturin_using_subcommand new" -l mixed -d 'Use mixed Rust/Python project layout'
complete -c maturin -n "__fish_maturin_using_subcommand new" -l src -d 'Use Python first src layout for mixed Rust/Python project'
complete -c maturin -n "__fish_maturin_using_subcommand new" -s v -l verbose -d 'Use verbose output'
complete -c maturin -n "__fish_maturin_using_subcommand new" -s h -l help -d 'Print help (see more with \'--help\')'
complete -c maturin -n "__fish_maturin_using_subcommand generate-ci" -s m -l manifest-path -d 'Path to Cargo.toml' -r -F
complete -c maturin -n "__fish_maturin_using_subcommand generate-ci" -s o -l output -d 'Output path' -r -F
complete -c maturin -n "__fish_maturin_using_subcommand generate-ci" -l platform -d 'Platform support' -r -f -a "{all\t'All',manylinux\t'Manylinux',musllinux\t'Musllinux',windows\t'Windows',macos\t'macOS',emscripten\t'Emscripten'}"
complete -c maturin -n "__fish_maturin_using_subcommand generate-ci" -l pytest -d 'Enable pytest'
complete -c maturin -n "__fish_maturin_using_subcommand generate-ci" -l zig -d 'Use zig to do cross compilation'
complete -c maturin -n "__fish_maturin_using_subcommand generate-ci" -s v -l verbose -d 'Use verbose output'
complete -c maturin -n "__fish_maturin_using_subcommand generate-ci" -s h -l help -d 'Print help (see more with \'--help\')'
complete -c maturin -n "__fish_maturin_using_subcommand pep517; and not __fish_seen_subcommand_from write-dist-info build-wheel write-sdist help" -s v -l verbose -d 'Use verbose output'
complete -c maturin -n "__fish_maturin_using_subcommand pep517; and not __fish_seen_subcommand_from write-dist-info build-wheel write-sdist help" -s h -l help -d 'Print help (see more with \'--help\')'
complete -c maturin -n "__fish_maturin_using_subcommand pep517; and not __fish_seen_subcommand_from write-dist-info build-wheel write-sdist help" -f -a "write-dist-info" -d 'The implementation of prepare_metadata_for_build_wheel'
complete -c maturin -n "__fish_maturin_using_subcommand pep517; and not __fish_seen_subcommand_from write-dist-info build-wheel write-sdist help" -f -a "build-wheel" -d 'Implementation of build_wheel'
complete -c maturin -n "__fish_maturin_using_subcommand pep517; and not __fish_seen_subcommand_from write-dist-info build-wheel write-sdist help" -f -a "write-sdist" -d 'The implementation of build_sdist'
complete -c maturin -n "__fish_maturin_using_subcommand pep517; and not __fish_seen_subcommand_from write-dist-info build-wheel write-sdist help" -f -a "help" -d 'Print this message or the help of the given subcommand(s)'
complete -c maturin -n "__fish_maturin_using_subcommand pep517; and __fish_seen_subcommand_from write-dist-info" -l compatibility -d 'Control the platform tag on linux' -r
complete -c maturin -n "__fish_maturin_using_subcommand pep517; and __fish_seen_subcommand_from write-dist-info" -s i -l interpreter -d 'The python versions to build wheels for, given as the executables of interpreters such as `python3.9` or `/usr/bin/python3.8`' -r -F
complete -c maturin -n "__fish_maturin_using_subcommand pep517; and __fish_seen_subcommand_from write-dist-info" -s b -l bindings -d 'Which kind of bindings to use' -r -f -a "{pyo3\t'',pyo3-ffi\t'',cffi\t'',uniffi\t'',bin\t''}"
complete -c maturin -n "__fish_maturin_using_subcommand pep517; and __fish_seen_subcommand_from write-dist-info" -s o -l out -d 'The directory to store the built wheels in. Defaults to a new "wheels" directory in the project\'s target directory' -r -F
complete -c maturin -n "__fish_maturin_using_subcommand pep517; and __fish_seen_subcommand_from write-dist-info" -l auditwheel -d 'Audit wheel for manylinux compliance' -r -f -a "{repair\t'Audit and repair wheel for manylinux compliance',check\t'Check wheel for manylinux compliance, but do not repair',skip\t'Don\'t check for manylinux compliance'}"
complete -c maturin -n "__fish_maturin_using_subcommand pep517; and __fish_seen_subcommand_from write-dist-info" -s j -l jobs -d 'Number of parallel jobs, defaults to # of CPUs' -r
complete -c maturin -n "__fish_maturin_using_subcommand pep517; and __fish_seen_subcommand_from write-dist-info" -l profile -d 'Build artifacts with the specified Cargo profile' -r
complete -c maturin -n "__fish_maturin_using_subcommand pep517; and __fish_seen_subcommand_from write-dist-info" -s F -l features -d 'Space or comma separated list of features to activate' -r
complete -c maturin -n "__fish_maturin_using_subcommand pep517; and __fish_seen_subcommand_from write-dist-info" -l target -d 'Build for the target triple' -r
complete -c maturin -n "__fish_maturin_using_subcommand pep517; and __fish_seen_subcommand_from write-dist-info" -l target-dir -d 'Directory for all generated artifacts' -r -F
complete -c maturin -n "__fish_maturin_using_subcommand pep517; and __fish_seen_subcommand_from write-dist-info" -s m -l manifest-path -d 'Path to Cargo.toml' -r -F
complete -c maturin -n "__fish_maturin_using_subcommand pep517; and __fish_seen_subcommand_from write-dist-info" -l color -d 'Coloring: auto, always, never' -r
complete -c maturin -n "__fish_maturin_using_subcommand pep517; and __fish_seen_subcommand_from write-dist-info" -l config -d 'Override a configuration value (unstable)' -r
complete -c maturin -n "__fish_maturin_using_subcommand pep517; and __fish_seen_subcommand_from write-dist-info" -s Z -d 'Unstable (nightly-only) flags to Cargo, see \'cargo -Z help\' for details' -r
complete -c maturin -n "__fish_maturin_using_subcommand pep517; and __fish_seen_subcommand_from write-dist-info" -l timings -d 'Timing output formats (unstable) (comma separated): html, json' -r
complete -c maturin -n "__fish_maturin_using_subcommand pep517; and __fish_seen_subcommand_from write-dist-info" -l metadata-directory -d 'The metadata_directory argument to prepare_metadata_for_build_wheel' -r -F
complete -c maturin -n "__fish_maturin_using_subcommand pep517; and __fish_seen_subcommand_from write-dist-info" -s f -l find-interpreter -d 'Find interpreters from the host machine'
complete -c maturin -n "__fish_maturin_using_subcommand pep517; and __fish_seen_subcommand_from write-dist-info" -l skip-auditwheel -d 'Don\'t check for manylinux compliance'
complete -c maturin -n "__fish_maturin_using_subcommand pep517; and __fish_seen_subcommand_from write-dist-info" -s q -l quiet -d 'Do not print cargo log messages'
complete -c maturin -n "__fish_maturin_using_subcommand pep517; and __fish_seen_subcommand_from write-dist-info" -l all-features -d 'Activate all available features'
complete -c maturin -n "__fish_maturin_using_subcommand pep517; and __fish_seen_subcommand_from write-dist-info" -l no-default-features -d 'Do not activate the `default` feature'
complete -c maturin -n "__fish_maturin_using_subcommand pep517; and __fish_seen_subcommand_from write-dist-info" -l ignore-rust-version -d 'Ignore `rust-version` specification in packages'
complete -c maturin -n "__fish_maturin_using_subcommand pep517; and __fish_seen_subcommand_from write-dist-info" -s v -l verbose -d 'Use verbose output (-vv very verbose/build.rs output)'
complete -c maturin -n "__fish_maturin_using_subcommand pep517; and __fish_seen_subcommand_from write-dist-info" -l frozen -d 'Require Cargo.lock and cache are up to date'
complete -c maturin -n "__fish_maturin_using_subcommand pep517; and __fish_seen_subcommand_from write-dist-info" -l locked -d 'Require Cargo.lock is up to date'
complete -c maturin -n "__fish_maturin_using_subcommand pep517; and __fish_seen_subcommand_from write-dist-info" -l offline -d 'Run without accessing the network'
complete -c maturin -n "__fish_maturin_using_subcommand pep517; and __fish_seen_subcommand_from write-dist-info" -l future-incompat-report -d 'Outputs a future incompatibility report at the end of the build (unstable)'
complete -c maturin -n "__fish_maturin_using_subcommand pep517; and __fish_seen_subcommand_from write-dist-info" -l strip -d 'Strip the library for minimum file size'
complete -c maturin -n "__fish_maturin_using_subcommand pep517; and __fish_seen_subcommand_from write-dist-info" -s h -l help -d 'Print help (see more with \'--help\')'
complete -c maturin -n "__fish_maturin_using_subcommand pep517; and __fish_seen_subcommand_from build-wheel" -l compatibility -d 'Control the platform tag on linux' -r
complete -c maturin -n "__fish_maturin_using_subcommand pep517; and __fish_seen_subcommand_from build-wheel" -s i -l interpreter -d 'The python versions to build wheels for, given as the executables of interpreters such as `python3.9` or `/usr/bin/python3.8`' -r -F
complete -c maturin -n "__fish_maturin_using_subcommand pep517; and __fish_seen_subcommand_from build-wheel" -s b -l bindings -d 'Which kind of bindings to use' -r -f -a "{pyo3\t'',pyo3-ffi\t'',cffi\t'',uniffi\t'',bin\t''}"
complete -c maturin -n "__fish_maturin_using_subcommand pep517; and __fish_seen_subcommand_from build-wheel" -s o -l out -d 'The directory to store the built wheels in. Defaults to a new "wheels" directory in the project\'s target directory' -r -F
complete -c maturin -n "__fish_maturin_using_subcommand pep517; and __fish_seen_subcommand_from build-wheel" -l auditwheel -d 'Audit wheel for manylinux compliance' -r -f -a "{repair\t'Audit and repair wheel for manylinux compliance',check\t'Check wheel for manylinux compliance, but do not repair',skip\t'Don\'t check for manylinux compliance'}"
complete -c maturin -n "__fish_maturin_using_subcommand pep517; and __fish_seen_subcommand_from build-wheel" -s j -l jobs -d 'Number of parallel jobs, defaults to # of CPUs' -r
complete -c maturin -n "__fish_maturin_using_subcommand pep517; and __fish_seen_subcommand_from build-wheel" -l profile -d 'Build artifacts with the specified Cargo profile' -r
complete -c maturin -n "__fish_maturin_using_subcommand pep517; and __fish_seen_subcommand_from build-wheel" -s F -l features -d 'Space or comma separated list of features to activate' -r
complete -c maturin -n "__fish_maturin_using_subcommand pep517; and __fish_seen_subcommand_from build-wheel" -l target -d 'Build for the target triple' -r
complete -c maturin -n "__fish_maturin_using_subcommand pep517; and __fish_seen_subcommand_from build-wheel" -l target-dir -d 'Directory for all generated artifacts' -r -F
complete -c maturin -n "__fish_maturin_using_subcommand pep517; and __fish_seen_subcommand_from build-wheel" -s m -l manifest-path -d 'Path to Cargo.toml' -r -F
complete -c maturin -n "__fish_maturin_using_subcommand pep517; and __fish_seen_subcommand_from build-wheel" -l color -d 'Coloring: auto, always, never' -r
complete -c maturin -n "__fish_maturin_using_subcommand pep517; and __fish_seen_subcommand_from build-wheel" -l config -d 'Override a configuration value (unstable)' -r
complete -c maturin -n "__fish_maturin_using_subcommand pep517; and __fish_seen_subcommand_from build-wheel" -s Z -d 'Unstable (nightly-only) flags to Cargo, see \'cargo -Z help\' for details' -r
complete -c maturin -n "__fish_maturin_using_subcommand pep517; and __fish_seen_subcommand_from build-wheel" -l timings -d 'Timing output formats (unstable) (comma separated): html, json' -r
complete -c maturin -n "__fish_maturin_using_subcommand pep517; and __fish_seen_subcommand_from build-wheel" -s f -l find-interpreter -d 'Find interpreters from the host machine'
complete -c maturin -n "__fish_maturin_using_subcommand pep517; and __fish_seen_subcommand_from build-wheel" -l skip-auditwheel -d 'Don\'t check for manylinux compliance'
complete -c maturin -n "__fish_maturin_using_subcommand pep517; and __fish_seen_subcommand_from build-wheel" -s q -l quiet -d 'Do not print cargo log messages'
complete -c maturin -n "__fish_maturin_using_subcommand pep517; and __fish_seen_subcommand_from build-wheel" -l all-features -d 'Activate all available features'
complete -c maturin -n "__fish_maturin_using_subcommand pep517; and __fish_seen_subcommand_from build-wheel" -l no-default-features -d 'Do not activate the `default` feature'
complete -c maturin -n "__fish_maturin_using_subcommand pep517; and __fish_seen_subcommand_from build-wheel" -l ignore-rust-version -d 'Ignore `rust-version` specification in packages'
complete -c maturin -n "__fish_maturin_using_subcommand pep517; and __fish_seen_subcommand_from build-wheel" -s v -l verbose -d 'Use verbose output (-vv very verbose/build.rs output)'
complete -c maturin -n "__fish_maturin_using_subcommand pep517; and __fish_seen_subcommand_from build-wheel" -l frozen -d 'Require Cargo.lock and cache are up to date'
complete -c maturin -n "__fish_maturin_using_subcommand pep517; and __fish_seen_subcommand_from build-wheel" -l locked -d 'Require Cargo.lock is up to date'
complete -c maturin -n "__fish_maturin_using_subcommand pep517; and __fish_seen_subcommand_from build-wheel" -l offline -d 'Run without accessing the network'
complete -c maturin -n "__fish_maturin_using_subcommand pep517; and __fish_seen_subcommand_from build-wheel" -l future-incompat-report -d 'Outputs a future incompatibility report at the end of the build (unstable)'
complete -c maturin -n "__fish_maturin_using_subcommand pep517; and __fish_seen_subcommand_from build-wheel" -l strip -d 'Strip the library for minimum file size'
complete -c maturin -n "__fish_maturin_using_subcommand pep517; and __fish_seen_subcommand_from build-wheel" -l editable -d 'Build editable wheels'
complete -c maturin -n "__fish_maturin_using_subcommand pep517; and __fish_seen_subcommand_from build-wheel" -s h -l help -d 'Print help (see more with \'--help\')'
complete -c maturin -n "__fish_maturin_using_subcommand pep517; and __fish_seen_subcommand_from write-sdist" -l sdist-directory -d 'The sdist_directory argument to build_sdist' -r -F
complete -c maturin -n "__fish_maturin_using_subcommand pep517; and __fish_seen_subcommand_from write-sdist" -s m -l manifest-path -d 'The path to the Cargo.toml' -r -F
complete -c maturin -n "__fish_maturin_using_subcommand pep517; and __fish_seen_subcommand_from write-sdist" -s v -l verbose -d 'Use verbose output'
complete -c maturin -n "__fish_maturin_using_subcommand pep517; and __fish_seen_subcommand_from write-sdist" -s h -l help -d 'Print help (see more with \'--help\')'
complete -c maturin -n "__fish_maturin_using_subcommand pep517; and __fish_seen_subcommand_from help" -f -a "write-dist-info" -d 'The implementation of prepare_metadata_for_build_wheel'
complete -c maturin -n "__fish_maturin_using_subcommand pep517; and __fish_seen_subcommand_from help" -f -a "build-wheel" -d 'Implementation of build_wheel'
complete -c maturin -n "__fish_maturin_using_subcommand pep517; and __fish_seen_subcommand_from help" -f -a "write-sdist" -d 'The implementation of build_sdist'
complete -c maturin -n "__fish_maturin_using_subcommand pep517; and __fish_seen_subcommand_from help" -f -a "help" -d 'Print this message or the help of the given subcommand(s)'
complete -c maturin -n "__fish_maturin_using_subcommand completions" -s v -l verbose -d 'Use verbose output'
complete -c maturin -n "__fish_maturin_using_subcommand completions" -s h -l help -d 'Print help (see more with \'--help\')'
complete -c maturin -n "__fish_maturin_using_subcommand help; and not __fish_seen_subcommand_from build list-python develop sdist init new generate-ci pep517 completions help" -f -a "build" -d 'Build the crate into python packages'
complete -c maturin -n "__fish_maturin_using_subcommand help; and not __fish_seen_subcommand_from build list-python develop sdist init new generate-ci pep517 completions help" -f -a "list-python" -d 'Search and list the available python installations'
complete -c maturin -n "__fish_maturin_using_subcommand help; and not __fish_seen_subcommand_from build list-python develop sdist init new generate-ci pep517 completions help" -f -a "develop" -d 'Install the crate as module in the current virtualenv'
complete -c maturin -n "__fish_maturin_using_subcommand help; and not __fish_seen_subcommand_from build list-python develop sdist init new generate-ci pep517 completions help" -f -a "sdist" -d 'Build only a source distribution (sdist) without compiling'
complete -c maturin -n "__fish_maturin_using_subcommand help; and not __fish_seen_subcommand_from build list-python develop sdist init new generate-ci pep517 completions help" -f -a "init" -d 'Create a new cargo project in an existing directory'
complete -c maturin -n "__fish_maturin_using_subcommand help; and not __fish_seen_subcommand_from build list-python develop sdist init new generate-ci pep517 completions help" -f -a "new" -d 'Create a new cargo project'
complete -c maturin -n "__fish_maturin_using_subcommand help; and not __fish_seen_subcommand_from build list-python develop sdist init new generate-ci pep517 completions help" -f -a "generate-ci" -d 'Generate CI configuration'
complete -c maturin -n "__fish_maturin_using_subcommand help; and not __fish_seen_subcommand_from build list-python develop sdist init new generate-ci pep517 completions help" -f -a "pep517" -d 'Backend for the PEP 517 integration. Not for human consumption'
complete -c maturin -n "__fish_maturin_using_subcommand help; and not __fish_seen_subcommand_from build list-python develop sdist init new generate-ci pep517 completions help" -f -a "completions" -d 'Generate shell completions'
complete -c maturin -n "__fish_maturin_using_subcommand help; and not __fish_seen_subcommand_from build list-python develop sdist init new generate-ci pep517 completions help" -f -a "help" -d 'Print this message or the help of the given subcommand(s)'
complete -c maturin -n "__fish_maturin_using_subcommand help; and __fish_seen_subcommand_from pep517" -f -a "write-dist-info" -d 'The implementation of prepare_metadata_for_build_wheel'
complete -c maturin -n "__fish_maturin_using_subcommand help; and __fish_seen_subcommand_from pep517" -f -a "build-wheel" -d 'Implementation of build_wheel'
complete -c maturin -n "__fish_maturin_using_subcommand help; and __fish_seen_subcommand_from pep517" -f -a "write-sdist" -d 'The implementation of build_sdist'
